==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+71"/>
        <source>audience</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">publiczność</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">twórca</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Wymi&amp;ar
Wymiar
Wskaż położenie linii wymiarowej</translatorcomment>
        <translation type="unfinished">Wymiar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">levelOfDetail</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translatorcomment>--google--
Kontrolka licencjonowana
Kontrolka wymaga licencji podczas projektowania</translatorcomment>
        <translation type="unfinished">licencja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">perspektywa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translatorcomment>--google--
[FB00-FB4F] Alphabetic Presentation Forms
[FB50-FDFF] Arabic Presentation Forms-A
[FE70-FEFF] Arabic Presentation Forms-B</translatorcomment>
        <translation type="unfinished">prezentacja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">wydawca</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">przedmiot</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translatorcomment>--google--
Nienazwany
&lt;title&gt;o:pusty&lt;/title&gt;
Tytuł:</translatorcomment>
        <translation type="unfinished">tytuł</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Własne widżety
Zastępcze widżety</translatorcomment>
        <translation type="unfinished">Widżety</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1153"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przeglądarka bibliotek</translatorcomment>
        <translation type="unfinished">Przeglądarka bibliotek</translation>
    </message>
    <message>
        <location line="-1145"/>
        <source>Icon</source>
        <translatorcomment>--google--
XX ikona wybrana wyłączona
Widok z ikonkami
&amp;Ikonka:</translatorcomment>
        <translation type="unfinished">Ikona</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translatorcomment>--google--
Lista warstw
Lista bloków
Atrybuty filtru bieżącej dokumentacji (lista oddzielona przecinkami):</translatorcomment>
        <translation type="unfinished">Lista</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wybierz folder źródłowy</translation>
    </message>
    <message>
        <location line="+685"/>
        <source>Page %1 of %2</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Strona %1 z %2</translatorcomment>
        <translation type="unfinished">Strona %1 z %2</translation>
    </message>
    <message>
        <location line="+235"/>
        <source>Updating icons...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Aktualizowanie ikony ...</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+219"/>
        <source>Abort</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Otwieranie przerwane
Drukowanie przerwane</translatorcomment>
        <translation type="unfinished">Przerwij</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>File:</source>
        <translatorcomment>--ignored colon--
--file: qtconfig_pl.ts--
Niepoprawny plik UI: brak głównego elementu &lt;ui&gt;.
Niepoprawny plik UI: brak głównego elementu &lt;ui&gt;
&apos;%1&apos; nie jest poprawnym profilem: %2</translatorcomment>
        <translation type="unfinished">Plik:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Dodaj do katalogu:
Wirtualny katalog:</translatorcomment>
        <translation type="unfinished">Katalog:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Licencja:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Parametry jak:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Twórca:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Aktualizowanie indeksu biblioteki:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>DB error</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Błąd DB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">LibraryBrowser Plugin: nie można połączyć się z DB. Błąd kierowcy: Błąd bazy danych: Plik bazy danych: przeglądarka Biblioteka nie będzie dostępna.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translatorcomment>--google--
&amp;Wstaw blok
&amp;Wstaw obiekt z biblioteki</translatorcomment>
        <translation type="unfinished">Wstawić</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Edycja pliku skryptu ...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Otwórz plik SVG ...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
&amp;Otwórz...</translatorcomment>
        <translation type="unfinished">&amp;Otwórz...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translatorcomment>--ignored ...--
--file: linguist_pl.ts--</translatorcomment>
        <translation type="unfinished">&amp;Edycja...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przeglądarka plików</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż na ...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Usuń z ulubionych</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Dodaj do ulubionych</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Regeneruj Ikona</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Regeneruj Ikony</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przeglądarka Library</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Synchronizacja</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Aktualizacja indeksu wyszukiwania na starcie</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Opcje wyświetlania</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Rozmiar ikon:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Tryb wyświetlania:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Liczba pozycji wykazanych w wynikach wyszukiwania:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Źródła Biblioteka</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translatorcomment>--exact match--
--file: assistant_pl.ts--
Dodaj...</translatorcomment>
        <translation type="unfinished">Dodaj...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Usuń blok
&amp;Usuń blok</translatorcomment>
        <translation type="unfinished">Usuń</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Rozbij bloki oraz inne grupy obiektów
&amp;Powiel podłogę</translatorcomment>
        <translation type="unfinished">W górę</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Pobieranie informacji o dokumentacji...
Pobieranie informacji o dokumentacji
Anulowano pobieranie.</translatorcomment>
        <translation type="unfinished">W dół</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">System plików</translation>
    </message>
    <message>
        <source>Tags</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
[E0000-E007F] Tags
Tags</translatorcomment>
        <translation type="obsolete">Tags</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Look for:</source>
        <translatorcomment>--exact match--
--file: assistant_pl.ts--
Wy&amp;szukaj:
Wyszukaj:</translatorcomment>
        <translation type="unfinished">Wyszukaj:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wyczyść tekst
Wyczyść &amp;menu</translatorcomment>
        <translation type="unfinished">Wyczyść</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Z&amp;najdź w tekście...
Z&amp;najdź w tekście
Znajdź w tekście...</translatorcomment>
        <translation type="unfinished">Znajdź</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Resetowanie wybór znacznika</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translatorcomment>--google--
&lt;title&gt;o:pusty&lt;/title&gt;</translatorcomment>
        <translation type="obsolete">about: blank</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Favorites</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Ulubione</translatorcomment>
        <translation type="unfinished">Ulubione</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Insert selected item into drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Aktualizacja DB z systemem plików</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Poziomy
Pionowy</translatorcomment>
        <translation type="unfinished">0</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+72"/>
        <source>audience</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>publiczność</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>twórca</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Wymi&amp;ar
Wymiar
Wskaż położenie linii wymiarowej</translatorcomment>
        <translation>wymiar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>levelOfDetail</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translatorcomment>--google--
Kontrolka licencjonowana
Kontrolka wymaga licencji podczas projektowania</translatorcomment>
        <translation>licencja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>perspektywa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translatorcomment>--google--
[FB00-FB4F] Alphabetic Presentation Forms
[FB50-FDFF] Arabic Presentation Forms-A
[FE70-FEFF] Arabic Presentation Forms-B</translatorcomment>
        <translation>prezentacja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>wydawca</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>temat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translatorcomment>--google--
Nienazwany
&lt;title&gt;o:pusty&lt;/title&gt;
Tytuł:</translatorcomment>
        <translation>tytuł</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Własne widżety
Zastępcze widżety</translatorcomment>
        <translation>Widżety</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1158"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przeglądarka bibliotek</translatorcomment>
        <translation>Przeglądarka kolekcji</translation>
    </message>
    <message>
        <location line="-1150"/>
        <source>Icon</source>
        <translatorcomment>--google--
XX ikona wybrana wyłączona
Widok z ikonkami
&amp;Ikonka:</translatorcomment>
        <translation>Ikony</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translatorcomment>--google--
Lista warstw
Lista bloków
Atrybuty filtru bieżącej dokumentacji (lista oddzielona przecinkami):</translatorcomment>
        <translation>Lista</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wybór katalogu źródłowego</translation>
    </message>
    <message>
        <location line="+688"/>
        <source>Page %1 of %2</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Strona %1 z %2</translatorcomment>
        <translation>Strona %1 z %2</translation>
    </message>
    <message>
        <location line="+237"/>
        <source>Updating icons...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Uaktualnianie ikon...</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+219"/>
        <source>Abort</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Otwieranie przerwane
Drukowanie przerwane</translatorcomment>
        <translation>Przerwij</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>File:</source>
        <translatorcomment>--ignored colon--
--file: qtconfig_pl.ts--
Niepoprawny plik UI: brak głównego elementu &lt;ui&gt;.
Niepoprawny plik UI: brak głównego elementu &lt;ui&gt;
&apos;%1&apos; nie jest poprawnym profilem: %2</translatorcomment>
        <translation>Plik:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Dodaj do katalogu:
Wirtualny katalog:</translatorcomment>
        <translation>Katalog:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Licencja:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Parametry jak:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Twórca:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Uaktualnianie indeksu kolekcji:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>DB error</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Błąd bazy danych</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wtyczka LibraryBrowser: nie można połączyć się z bazą danych.
Błąd sterownika: %1
Błąd bazy danych: %2
Plik bazy danych: %3
Przeglądarka kolekcji nie będzie dostępna.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation>Usunięto źródło z kolekcji części: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation>Wymuś uaktualnienie bazy danych.</translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translatorcomment>--google--
&amp;Wstaw blok
&amp;Wstaw obiekt z biblioteki</translatorcomment>
        <translation>&amp;Wstaw</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Edytuj plik skryptu...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Otwórz plik &amp;SVG...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
&amp;Otwórz...</translatorcomment>
        <translation>&amp;Otwórz...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translatorcomment>--ignored ...--
--file: linguist_pl.ts--</translatorcomment>
        <translation>&amp;Edytuj...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Przeglądarka plików</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Wyświetl na %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Usuń z ulubionych</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Dodaj do ulubionych</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>U&amp;aktualnij ikonę</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>U&amp;aktualnij ikony</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Przeglądarka &amp;kolekcji</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Synchronizowanie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Uaktualnianie indeksu wyszukiwania podczas uruchamiania</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Opcje wyświetlania</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rozmiar ikon:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tryb wyświetlania:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Liczba pozycji wykazanych w wynikach wyszukiwania:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Źródła kolekcji</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translatorcomment>--exact match--
--file: assistant_pl.ts--
Dodaj...</translatorcomment>
        <translation>Dodaj...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Usuń blok
&amp;Usuń blok</translatorcomment>
        <translation>Usuń</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Rozbij bloki oraz inne grupy obiektów
&amp;Powiel podłogę</translatorcomment>
        <translation>W górę</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Pobieranie informacji o dokumentacji...
Pobieranie informacji o dokumentacji
Anulowano pobieranie.</translatorcomment>
        <translation>W dół</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>System plików</translation>
    </message>
    <message>
        <source>Tags</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
[E0000-E007F] Tags
Tags</translatorcomment>
        <translation type="obsolete">Tags</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation>Wyszukiwanie</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Look for:</source>
        <translatorcomment>--exact match--
--file: assistant_pl.ts--
Wy&amp;szukaj:
Wyszukaj:</translatorcomment>
        <translation>Wyszukanie:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wyczyść tekst
Wyczyść &amp;menu</translatorcomment>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Z&amp;najdź w tekście...
Z&amp;najdź w tekście
Znajdź w tekście...</translatorcomment>
        <translation>Wyszukaj</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyczyść wybór znacznika</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translatorcomment>--google--
&lt;title&gt;o:pusty&lt;/title&gt;</translatorcomment>
        <translation type="obsolete">about: blank</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Favorites</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Ulubione</translatorcomment>
        <translation>Ulubione</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Insert selected item into drawing</source>
        <translation>Wstaw zaznaczony obiekt do rysunku</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Uaktualnij bazę danych z systemu plików</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Poziomy
Pionowy</translatorcomment>
        <translation>0</translation>
    </message>
</context>
</TS>
